-- if the table exists, drop it so we can reload it
DROP TABLE IF EXISTS s70;

-- create the table with the following fields
CREATE TABLE s70 (
	filename VARCHAR(32),
	src_name VARCHAR(16),
	project_id VARCHAR(10),
	raj VARCHAR(20),
	decj VARCHAR(20),
 	data_type VARCHAR(128),
        obsfreq DECIMAL(32,16),
	bw DECIMAL(16,6),
	scanlen DECIMAL(32,20),
 	date VARCHAR(16),   
 	ut VARCHAR(16),   
 	MJD DECIMAL(32,26),
	rajd DOUBLE,
	decjd DOUBLE,
	gl DOUBLE,
	gb DOUBLE,
	bmaj FLOAT,
	bmin FLOAT,
	bpa FLOAT,
	dm DECIMAL(16,10),
	period DECIMAL(32,24),
 	nchan INT(6),        
	npol INT(6),
 	nbin INT(6),        
 	nsub INT(6),        
 	tsamp FLOAT,       
	nbits tinyint(3) unsigned,  
	nbeam tinyint(3) unsigned,
	cnfg VARCHAR(128),
 	inst VARCHAR(32),
 	rcvr VARCHAR(16),   
	hdrver VARCHAR(10),
	survey VARCHAR(10),
	telescope VARCHAR(16),
 	site VARCHAR(8),    
 	obsrvr VARCHAR(32),   
	data_loc VARCHAR(100),
 	file_size_bytes INT(32),
	PRIMARY KEY (filename, data_loc)
);

LOAD DATA LOCAL
INFILE "/pulsar/archive13/S70V/summary_S70.csv"
INTO TABLE s70
FIELDS TERMINATED BY ","
OPTIONALLY ENCLOSED BY "\""
IGNORE 1 LINES  -- this ignores the first line in the csv file which contains the column headers.
(filename,src_name,project_id,raj,decj,data_type,obsfreq,bw,scanlen,date,ut,MJD,rajd,decjd,gl,gb,bmaj,bmin,bpa,dm,period,nchan,npol,nbin,nsub,tsamp,nbits,nbeam,cnfg,inst,rcvr,hdrver,survey,telescope,site,obsrvr,data_loc,file_size_bytes);

UPDATE s70 SET bw = bw * nchan;


-- base coords for galactic coord transformation.
SET @ngpra=192.859508, @ngpdec=27.128336, @ascnode=32.932; 

-- if the table exists, drop it so we can reload it
DROP TABLE IF EXISTS obs;

-- create the table with the following fields
CREATE TABLE obs (
	filename VARCHAR(32),
	src_name VARCHAR(16),
	project_id VARCHAR(10),
	raj VARCHAR(20),
	decj VARCHAR(20),
 	data_type VARCHAR(128),
        obsfreq DECIMAL(32,16),
	bw DECIMAL(16,6),
	scanlen DECIMAL(32,20),
 	date VARCHAR(16),   
 	ut VARCHAR(16),   
 	MJD DECIMAL(32,26),
	rajd DOUBLE,
	decjd DOUBLE,
	gl DOUBLE,
	gb DOUBLE,
	bmaj FLOAT,
	bmin FLOAT,
	bpa FLOAT,
	dm DECIMAL(16,10),
	period DECIMAL(32,24),
 	nchan INT(6),        
	npol INT(6),
 	nbin INT(6),        
 	nsub INT(6),        
 	tsamp FLOAT,       
	nbits tinyint(3) unsigned,  
	nbeam tinyint(3) unsigned,
	cnfg VARCHAR(128),
 	inst VARCHAR(32),
 	rcvr VARCHAR(16),   
	hdrver VARCHAR(10),
	survey VARCHAR(10),
	telescope VARCHAR(16),
 	site VARCHAR(8),    
 	obsrvr VARCHAR(32),   
	data_loc VARCHAR(100),
 	file_size_bytes INT(32),
	PRIMARY KEY (filename, data_loc)
)
 SELECT
	o.filename, 
	o.pulsar_name as src_name,
	NULL as project_id,
	concat(raj_hour,':',raj_minute,':',raj_second) as raj,
	case 
	     when (o.pulsar_name like '%-%') 
		then concat('-',abs(o.decj_degree),':',o.decj_minute,':',o.decj_second)
	     when (o.decj_degree<0.) 
		then concat('-',abs(o.decj_degree),':',o.decj_minute,':',o.decj_second)
             else concat(abs(o.decj_degree),':',o.decj_minute,':',o.decj_second) 
    	end as decj,
	o.data_type,
	o.freq as obsfreq,
	o.bw as bw,
	o.length as scanlen, 
	o.date as date,
	o.ut as ut,
	o.MJD as MJD,
        (o.raj_hour+o.raj_minute/60.+o.raj_second/3600.)*15. as rajd,
        case when o.pulsar_name like '%-%'
		then -1.*(abs(o.decj_degree)+o.decj_minute/60.+o.decj_second/3600.)
             when (o.decj_degree<0.)
		then -1.*(abs(o.decj_degree)+o.decj_minute/60.+o.decj_second/3600.)
             else abs(o.decj_degree)+o.decj_minute/60.+o.decj_second/3600. 
	end as decjd,
	NULL as gl, 
	NULL as gb,
	(1.2*(299792458./(o.freq*1.e6))/64.) * 180./pi() as BMAJ,
	(1.2*(299792458./(o.freq*1.e6))/64.) * 180./pi() as BMIN,
	0. as BPA,
	o.dm, 
	o.period, 
	o.nchan,
	o.npol,
	o.nbin, 
	o.nsub, 
	o.tsamp,
	NULL as nbits,
	o.nbeam, 
	o.cnfg,
	o.inst,
	o.rcvr,
	NULL as hdrver,
	NULL as survey,
	'PARKES' as telescope,
	o.site as site,
	o.obsrvr,
	o.data_loc, 
	o.file_size_bytes
 FROM OLDobservations as o;


UPDATE obs
  SET	gl = case 
		when degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode > 0 
	        then degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode
       		else degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode + 360.
	   end,
	gb = (degrees( asin( cos(radians(decjd))*cos(radians(@ngpdec))*cos(radians(rajd-@ngpra)) + sin(radians(decjd))*sin(radians(@ngpdec)))));

--------------------------------------
-- Now create the new cals table
--
-- if the table exists, drop it so we can reload it
DROP TABLE IF EXISTS calib;

-- create the table with the following fields
CREATE TABLE calib (
	filename VARCHAR(32),
	src_name VARCHAR(16),
	project_id VARCHAR(10),
	raj VARCHAR(20),
	decj VARCHAR(20),
 	data_type VARCHAR(128),
        obsfreq DECIMAL(32,16),
	bw DECIMAL(16,6),
	scanlen DECIMAL(32,20),
 	date VARCHAR(16),   
 	ut VARCHAR(16),   
 	MJD DECIMAL(32,26),
	rajd DOUBLE,
	decjd DOUBLE,
	gl DOUBLE,
	gb DOUBLE,
	bmaj FLOAT,
	bmin FLOAT,
	bpa FLOAT,
	dm DECIMAL(16,10),
	period DECIMAL(32,24),
 	nchan INT(6),        
	npol INT(6),
 	nbin INT(6),        
 	nsub INT(6),        
 	tsamp FLOAT,       
	nbits tinyint(3) unsigned,  
	nbeam tinyint(3) unsigned,
	cnfg VARCHAR(128),
 	inst VARCHAR(32),
 	rcvr VARCHAR(16),   
	hdrver VARCHAR(10),
	survey VARCHAR(10),
	telescope VARCHAR(16),
 	site VARCHAR(8),    
 	obsrvr VARCHAR(32),   
	data_loc VARCHAR(100),
 	file_size_bytes INT(32),
	PRIMARY KEY (filename, data_loc)
)
 SELECT
	c.filename, 
	c.pulsar_name as src_name,
	NULL as project_id,
	concat(raj_hour,':',raj_minute,':',raj_second) as raj,
	case 
	     when (c.pulsar_name like '%-%') 
		then concat('-',abs(c.decj_degree),':',c.decj_minute,':',c.decj_second)
	     when (c.decj_degree<0.) 
		then concat('-',abs(c.decj_degree),':',c.decj_minute,':',c.decj_second)
             else concat(abs(c.decj_degree),':',c.decj_minute,':',c.decj_second) 
    	end as decj,
	c.data_type,
	c.freq as obsfreq,
	c.bw as bw,
	NULL as scanlen, 
	NULL as date,
	NULL as ut,
	c.MJD as MJD,
        (c.raj_hour+c.raj_minute/60.+c.raj_second/3600.)*15. as rajd,
        case when c.pulsar_name like '%-%' 
		then -1.*(abs(c.decj_degree)+c.decj_minute/60.+c.decj_second/3600.)
             when (c.decj_degree<0.)
		then -1.*(abs(c.decj_degree)+c.decj_minute/60.+c.decj_second/3600.)
             else abs(c.decj_degree)+c.decj_minute/60.+c.decj_second/3600. 
	end as decjd,
	NULL as gl, 
	NULL as gb,
	(1.2*(299792458./(c.freq*1.e6))/64.) * 180./pi() as BMAJ,
	(1.2*(299792458./(c.freq*1.e6))/64.) * 180./pi() as BMIN,
	0. as BPA,
	c.dm, 
	c.period, 
	c.nchan,
	c.npol,
	c.nbin, 
	c.nsub, 
	NULL as tsamp,
	NULL as nbits,
	NULL as nbeam, 
	c.cnfg,
	c.inst,
	c.rcvr,
	NULL as hdrver,
	NULL as survey,
	'PARKES' as telescope,
	c.site as site,
	c.obsrvr,
	c.data_loc, 
	c.file_size_bytes
 FROM OLDcals as c;

UPDATE calib
  SET	gl = case 
		when degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode > 0 
	        then degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode
       		else degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode + 360.
	   end,
	gb = (degrees( asin( cos(radians(decjd))*cos(radians(@ngpdec))*cos(radians(rajd-@ngpra)) + sin(radians(decjd))*sin(radians(@ngpdec)))));


-- Now purge the repeated entries due to the symbolic links in the scrunch directories
--
-- The scrunch directories all have the same name as the regular directories, but end in S
-- eg. J0437-4715 <--> J0437-4715S

DELETE from obs
 WHERE data_loc like binary '%S';

DELETE from calib
 WHERE data_loc like binary '%S';